@@ -36,6 +36,16 @@ class DataSource(object):
         Example: "Daily events for Alpha Sensor"
         """
 
+        alt_names = params.get("alt_names", [])
+        if not isinstance(alt_names, list):
+            alt_names = [alt_names]
+        alt_names = [str(x) for x in alt_names]
+        self.alt_names = alt_names
+        """
+        list: Alternative names for the dataset
+        Example: "['txn_charges']"
+        """
+
         self.version = params.get("version", "v1")
         """
         str: Version
@@ -110,7 +120,23 @@ class DataSource(object):
                 "path": "%(data_root)s/shared/datasets/athena/v2/availability"
               }
            ]
+         """
+
+        self.registry = None
         """
+        object: Dataset manager object
+        """
+
+    def matches(self, names):
+        """
+        Check if the dataset has a particular name
+        """
+        if not isinstance(names, list):
+            names = [names]
+
+        matches = [((name == self.name) or (name in self.alt_names)) \
+                                   for name in names]
+        return any(matches)
 
     def set_resolve(self, resolve):
         """
@@ -120,6 +146,12 @@ class DataSource(object):
         assert len(resolve) > 0
         self.resolve.update(resolve)
 
+    def set_registry(self, registry):
+        """
+        Set the registry object
+        """
+        self.registry = registry
+
     def get_paths(self):
         """
         Return the available paths (full list of dictionaries,
@@ -722,8 +754,24 @@ class Dataset(DataSource):
 
         metadata["end"] = datetime.now()
 
+        # Note the access metadata
+        if ((self.registry is not None) and
+            (hasattr(self.registry, "access")) and
+            (callable(self.registry.access))):
+            self.registry.access(self, metadata, nature="read")
+
         return df, metadata
 
+    def write_data_note(
+        self,
+            metadata
+    ):
+        # Note the access metadata
+        if ((self.registry is not None) and
+            (hasattr(self.registry, "access")) and
+            (callable(self.registry.access))):
+            self.registry.access(self, metadata, nature="read")
+
 
 class DatabaseTable(DataSource):
     def __init__(self, params, *args, **kwargs):
@@ -892,6 +940,11 @@ class DatasetRegistry(object):
         """
         self.commands = kwargs.get("commands", get_commands())
         self.resolve = kwargs.get("resolve", {})
+        self.state = kwargs.get('state', None)
+        self.transform = kwargs.get('transform', None)
+        if ((self.state is None) and (hasattr(self.transform, 'state'))):
+            self.state = getattr(self.transform, 'state')
+
         self.datasets = []
         self.validate()
 
@@ -943,10 +996,12 @@ class DatasetRegistry(object):
             for item in items:
                 assert isinstance(item, DataSource)
                 item.set_resolve(self.resolve)
+                item.set_registry(self)
             self.datasets.extend(items)
         else:
             assert isinstance(items, DataSource)
             items.set_resolve(self.resolve)
+            item.set_registry(self)
             self.datasets.append(items)
 
     def set_resolve(self, resolve):
@@ -977,14 +1032,26 @@ class DatasetRegistry(object):
         """
         return [str(d) for d in self.datasets]
 
-    def find(self, name):
+    def find(self, names):
         """
         Find a dataset in the registry.
 
         Args:
-            name (str): Name of the dataset
+            names (str): Name of the dataset
         """
+        if not isinstance(names, (list, str)):
+            raise Exception(f"Unexpected dataset name(s): {names}")
+
         for d in self.datasets:
-            if d.name == name:
+            if d.matches(names):
                 return d
+
         return None
+
+    def access(self, dataset, metadata, nature='read-write'):
+
+        if self.state is None:
+            # Nothing to be done
+            return
+
+        self.state.make_dataset_access_note(dataset, metadata, nature)
