@@ -1226,6 +1226,32 @@ def populate(context={}):
                             print(orangebg("data_root exists: {}".format(data_root)))
 
 
+    enrich_root = os.environ["ENRICH_ROOT"]
+    activate_cmd = None
+    if "VIRTUAL_ENV" in os.environ:
+        venv_root = os.environ["VIRTUAL_ENV"]
+        venv_name = os.path.basename(venv_root)
+        activate_cmd = f"source {venv_name}/bin/activate"
+    elif "CONDA_PREFIX" in os.environ:
+        venv_root = os.environ["CONDA_PREFIX"]
+        venv_name = os.path.basename(venv_root)
+        activate_cmd = f"conda activate {venv_name}"
+
+    if activate_cmd is None:
+        print(greenbg("env.sh not created"))
+        return
+
+    envsh = f"""\
+{activate_cmd}
+#workon {venv_name}
+export ENRICH_ROOT={enrich_root}
+"""
+
+    with open(os.path.join(enrich_root, "env.sh"), "w") as fd:
+        fd.write(envsh)
+    print(greenbg("env.sh created"))
+
+
 def checkenv(validate_only=False, context={}):
     """
     Check whether environment is correctly configured
