@@ -89,8 +89,8 @@ def _start(commands):
         venv_root = os.environ["VIRTUAL_ENV"]
         venv_name = os.path.basename(venv_root)
         install_settings = [
-            'echo "#source {}/bin/activate" > $ENRICH_ROOT/env.sh'.format(venv_root),
-            'echo "workon {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
+            'echo "source {}/bin/activate" > $ENRICH_ROOT/env.sh'.format(venv_root),
+            'echo "#workon {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
         ]
     elif "CONDA_PREFIX" in os.environ:
         venv_root = os.environ["CONDA_PREFIX"]
@@ -129,7 +129,11 @@ def _start(commands):
             "description": "[OPTIONAl] Create a simple settings file",
             "cmd": [
                 "# file to be sourced before you start working. use the appropriate",
-                "# environment activation mechanism",
+                "# environment activation mechanism. Check the script generated by",
+                "# populate command",
+                "$ cat $ENRICH_ROOT/env.sh"
+                "",
+                "If the file doesnt exist or doesnt look right, use the following"
             ]
             + install_settings
             + [
@@ -166,16 +170,19 @@ def _start(commands):
         },
         {"cmd": ["cd Marketing"], "description": "Change to usecase"},
         {
-            "description": "Bootstrap a transform",
+            "description": "Bootstrap a transform. Transform is a python module. It could be a single file, directory or a full package",
             "cmd": [
-                "# Will create a python script",
-                "enrichpkg bootstrap -c transform-simple -p transforms/helloworld.py",
-                "# Will create a python module",
-                "enrichpkg bootstrap -c transform-simple -p transforms/helloworld",
-                "# Will create a python package",
-                "enrichpkg bootstrap -c transform-package -p transforms/helloworld",
-                "# Will create a hello world script",
+                "# Will create an example hello world script",
                 "enrichpkg bootstrap -c transform-helloworld -p transforms/helloworld.py",
+                "",
+                "# Will create a more simple python script that is more complex than helloworld",
+                "enrichpkg bootstrap -c transform-simple -p transforms/simplefile.py",
+                "",
+                "# Will create a python module (a full directory)",
+                "enrichpkg bootstrap -c transform-simple -p transforms/simpledir",
+                "",
+                "# Will create a python package. Dont use this unless you are sure",
+                "enrichpkg bootstrap -c transform-package -p transforms/simplepackage",
             ],
         },
         {
